@@ -2,7 +2,7 @@ use strict 'vars', 'subs';
                                                                                                                                    # $VERSION information.
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.2.1'; # TRIAL
+$DBIx::Squirrel::VERSION = '1.2.2'; # TRIAL
 use warnings;
 use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
 use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
@@ -17,7 +17,7 @@ DBIx::Squirrel - A module for working with databases
 
 =head1 VERSION
 
-version 1.2.1
+version 1.2.2
 
 =head1 SYNOPSIS
 
@@ -409,7 +409,7 @@ Helper semantics deal with three common types of interaction:
 =item * B<Establishing an association>
 
 Before it can be used, a helper must first be associated with a database
-entity. This accomplished by passing the function single argument: a
+entity. This is accomplished by passing the function single argument: a
 reference to the associated object.
 
 Once established, associations are I<sticky> and cannot easily be undone.
@@ -427,10 +427,11 @@ When no association exists in this scenario, a helper returns C<undef>.
 
 =item * B<Addressing an association>
 
-Addressing an association amounts to doing something meaningful with it.
+Addressing an association amounts to doing something meaningful with it,
+and we accomplish this by calling the helper function with one or more
+arguments.
 
-We do this by calling the helper function with one or more arguments. Once
-associated with a database object, a helper function will any arguments
+Once associated with a database object, a helper function will any arguments
 that are passed to it and send a version of these to the database object
 method that imbues meaning to the interaction.
 
@@ -449,13 +450,12 @@ methods respectively.
 
 =back
 
-Clearly there is a paradox here, and it centres around statements expect no
-bind-values.
-
-Optionally, you may enclose any arguments inside anonymous array or hash. In
-order to coerce the helper into performing the execution, you are allowed to
-pass an empty array reference (C<[]>) or hash reference (C<{}>), or resolve
-the association and call the relevant method manually.
+B<Clearly there is a paradox here>, which centres around those statements
+and iterators expecting I<no bind-values>. In order to smooth-out this wrinkle,
+you can opt to enclose arguments inside an anonymous array or hash. When no
+bind-values are expected, you can coerce the helper into performing the
+execution by passing an empty array or hash reference. Alternatively, you
+could just resolve the association and call the relevant method manually.
 
 =back
 
@@ -463,12 +463,12 @@ the association and call the relevant method manually.
 
 =over
 
-=item 1.
+=item *
 
 Let us do a full worked example. We will connect to a database, create and
 work with two result sets, one of which expects a single bind-value. Some
-concepts will be expanded upon later, but it might be helpful to dip a
-toe in the water ahead of time:
+concepts will be expanded upon and improved later, but it might be helpful
+to dip a toe in the water ahead of time:
 
     use DBIx::Squirrel database_objects => [ qw/db artists artist/ ];
 
@@ -495,46 +495,97 @@ toe in the water ahead of time:
     print artist('Aerosmith')->single->ArtistId, "\n";
 
     # Iterate over the "artists" result set, printing the Name-column for
-    # each artist:
+    # each artist. We don't need to trigger execution manually because
+    # the "next" method will do that for us, if it is necessary.
 
     while ( artists->next ) {
         print $_->Name, "\n";
     };
 
+=back
+
+=head2 Connecting to databases
+
+Connecting to a database using C<DBIx::Squirrel> may be done exactly as it
+would when using the C<DBI>'s C<connect_cached> and C<connect> methods.
+
+The C<connect> method implemented by the C<DBIx::Squirrel> package does,
+however, offer an alternative form:
+
+    $new_dbh = DBIx::Squirrel->connect($original_dbh, \%attr);
+
+This form clones another connection object and returns a brand object that
+is blessed using the same class that invoked the C<connect> method. Objects
+being cloned are allowed to be those created by the C<DBI> or any of its
+subclasses, C<DBIx::Squirrel> being one of those.
+
+=head2 Preparing statements
+
+Preparing a statement using C<DBIx::Squirrel> may be done exactly as
+it would be done using the C<DBI>'s C<prepare_cached> and C<prepare>
+methods.
+
+One nice quality-of-life feature offered by C<DBIx::Squirrel>'s own
+implementation of the C<prepare_cached> and C<prepare> methods is
+its built-in support for a variety of placeholder styles:
+
+=over
+
+=item * named (C<:name>);
+
+=item * positional (C<:number>, C<$number>, C<?number>);
+
+=item * legacy (C<?>)
 
 =back
 
-=head2 Database connection
+Regardless of your C<DBD> driver or your preferred style, statements
+will be normalised to the legacy placeholder (C<?>) by the time they
+are executed.
 
-Connecting to a database using C<DBIx::Squirrel> works the same
-way as it does when using the C<DBI> C<connect> and C<connect_cached>
-methods. The C<DBIx::Squirrel> C<connect> method, however, can also
-accept a database handle in place of a datasource name. The database
-handle can even be a reference to a C<DBI> object. The original database
-connection will be cloned as as C<DBIx::Squirrel> object.
+Use your preferred style or the style that most helps your query to
+be reasoned by others.
 
-=head2 Statement preparation
+=head4 Examples
 
 =over
 
 =item *
 
-Both C<prepare> and C<prepare_cached> methods continue to work as
-as they do in the C<DBI>, though they will also accept a statement
-handles in place of a statement strings. Again, this is useful when
-the intention is to prepare a C<DBI> statement object and represent
-it as a C<DBIx::Squirrel> statement object.
+Legacy placeholders (C<?>):
+
+    $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=? LIMIT 1');
+    $res = $sth->execute('Aerosmith');
 
 =item *
 
-Statements may be prepared using any one of a number of parameter
-placeholder styles, with support provided for named and a variety
-of positional styles. Styles supported are C<:name>, C<?1>, C<$1>,
-C<:1> and C<?>. Whether you prefer to use a particular style, or
-you are converting queries to run on a different database engine,
-any of these style will work regardless of the driver in use.
+SQLite positional placeholders (C<?number>):
 
-=back
+    $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=?1 LIMIT 1');
+    $res = $sth->execute('Aerosmith');
+
+=item *
+
+PostgreSQL positional placeholders (C<$number>):
+
+    $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=$1 LIMIT 1');
+    $res = $sth->execute('Aerosmith');
+
+=item *
+
+Oracle positional placeholders (C<:number>):
+
+    $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=:1 LIMIT 1');
+    $res = $sth->execute('Aerosmith');
+
+=item *
+
+Oracle named placeholders (C<:number>):
+
+    $sth = $dbh->prepare('SELECT * FROM artists WHERE Name=:Name LIMIT 1');
+    $res = $sth->execute(Name => 'Aerosmith');
+
+=back 
 
 =head2 Results processing
 
